==> libreoffice-fresh-sdk-24.8.4-2-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/search/all_2.js <==
var searchData=
[
  ['basemutex_0',['BaseMutex',['../a01026.html',1,'cppu']]],
  ['basemutex_2ehxx_1',['basemutex.hxx',['../a00362.html',1,'']]],
  ['basereference_2',['BaseReference',['../a01966.html',1,'com::sun::star::uno']]],
  ['basic_20logging_20functionality_3',['Basic logging functionality.',['../a02540.html',1,'']]],
  ['bcomplete_4',['bComplete',['../a00898.html#a5554ca9c80e573aba7b98aaab7630025',1,'_typelib_TypeDescription']]],
  ['bdisposed_5',['bDisposed',['../a01874.html#a929dd79785e30217bc7d53152c1b455a',1,'cppu::OBroadcastHelperVar']]],
  ['begin_6',['begin',['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence::begin()'],['../a01010.html#abe93b8603cfb316737b269bc76475187',1,'com::sun::star::uno::Sequence::begin() const']]],
  ['bin_7',['bIn',['../a00918.html#aa87139c0f6c1cc171cb401ff91a6198a',1,'_typelib_MethodParameter::bIn'],['../a00946.html#a4e3c822420f62a1ae07d401247ed4e2c',1,'_typelib_Parameter_Init::bIn']]],
  ['bind_8',['bind',['../a00858.html#a80d4fbebc159b4e4c2b8b60d3f5ff06e',1,'osl::Socket']]],
  ['bindispose_9',['bInDispose',['../a01874.html#a57c18e5807a8402f77d4769b1bc611d3',1,'cppu::OBroadcastHelperVar']]],
  ['blateinitservice_10',['bLateInitService',['../a01326.html#abaeb329d0b5d020ff3fec6ad46f4532f',1,'cppu::ContextEntry_Init']]],
  ['bondemand_11',['bOnDemand',['../a00898.html#a774f9c5fc72998b566fbfb3f58700393',1,'_typelib_TypeDescription']]],
  ['boneway_12',['bOneWay',['../a00926.html#acba9d6edd1ef75f8d760b6a1c2b59d7f',1,'_typelib_InterfaceMethodTypeDescription']]],
  ['boolean_13',['boolean',['../a00666.html#aa54c42c611eb44213b12e708043c9eda',1,'rtl::OString::boolean()'],['../a00754.html#ace4355afd5260ff7cf87a071fad6e1f2',1,'rtl::OUString::boolean()']]],
  ['bootstrap_14',['Bootstrap',['../a00610.html',1,'rtl::Bootstrap'],['../a00610.html#a7c411aba5c30fa1af8c6d53d02f18897',1,'rtl::Bootstrap::Bootstrap()'],['../a00610.html#a91097cd6f5d7a58469680b6915a81306',1,'rtl::Bootstrap::Bootstrap(const rtl::OUString &amp;iniName)']]],
  ['bootstrap_15',['bootstrap',['../a00537.html#ae1242c73574aa1cd60dca5361bec138c',1,'cppu']]],
  ['bootstrap_2eh_16',['bootstrap.h',['../a00077.html',1,'']]],
  ['bootstrap_2ehxx_17',['bootstrap.hxx',['../a02542.html',1,'(Global Namespace)'],['../a02545.html',1,'(Global Namespace)']]],
  ['bootstrapexception_18',['BootstrapException',['../a01030.html',1,'cppu::BootstrapException'],['../a01030.html#a4284f692e076b8c4855f6114d0b774cf',1,'cppu::BootstrapException::BootstrapException()'],['../a01030.html#a8c61f5925bff77185e816993b7761484',1,'cppu::BootstrapException::BootstrapException(const ::rtl::OUString &amp;rMessage)'],['../a01030.html#afe53d91ab3b69e94c8fea478a7a43a33',1,'cppu::BootstrapException::BootstrapException(const BootstrapException &amp;e)']]],
  ['boundlisteners_19',['BoundListeners',['../a01890.html',1,'cppu::PropertySetMixinImpl::BoundListeners'],['../a01890.html#af88d9d09a3f1f435c21a675d861ef476',1,'cppu::PropertySetMixinImpl::BoundListeners::BoundListeners()']]],
  ['bout_20',['bOut',['../a00918.html#ad5c88a40ec2f87cc2884efe5e8bd88d0',1,'_typelib_MethodParameter::bOut'],['../a00946.html#abd69f9d107dcadf0bd897464288ebaf5',1,'_typelib_Parameter_Init::bOut']]],
  ['bparameterizedtype_21',['bParameterizedType',['../a00942.html#a5cdfddabc1d5d18deac8de1a3e6a7a5d',1,'_typelib_StructMember_Init']]],
  ['breadonly_22',['bReadOnly',['../a00930.html#abb9014766239aeb6a5abb6fa465b4b72',1,'_typelib_InterfaceAttributeTypeDescription']]],
  ['by_20osl_5fgetfilestatus_23',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
  ['by_20osl_5fgetvolumeinfo_24',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
  ['byteseq_2eh_25',['byteseq.h',['../a00083.html',1,'']]],
  ['byteseq_2ehxx_26',['byteseq.hxx',['../a00071.html',1,'']]],
  ['byteseq_5fnoacquire_27',['BYTESEQ_NOACQUIRE',['../a00532.html#af08c591ebecc68f9a8df5f98b25e7542a2eeb40d13b914b4160ea05f6ff7c1beb',1,'rtl']]],
  ['byteseq_5fnodefault_28',['BYTESEQ_NODEFAULT',['../a00532.html#a7416169ba5faa7926706f8972385a6a5ad62567965fea0883022c6c5b41a59f01',1,'rtl']]],
  ['bytesequence_29',['ByteSequence',['../a00614.html',1,'rtl::ByteSequence'],['../a00614.html#aba8a538c65b24ac37c9362497fbb61d8',1,'rtl::ByteSequence::ByteSequence()'],['../a00614.html#a3db75655f708f320589189e839922288',1,'rtl::ByteSequence::ByteSequence(const ByteSequence &amp;rSeq)'],['../a00614.html#a52d50f23e52348c97ba3eb96925a335a',1,'rtl::ByteSequence::ByteSequence(sal_Sequence *pSequence)'],['../a00614.html#aa30632f511c14417f3bc4e3c6afc24d7',1,'rtl::ByteSequence::ByteSequence(const sal_Int8 *pElements, sal_Int32 len)'],['../a00614.html#ab12880eb67f9defc60a7973894d3b3c6',1,'rtl::ByteSequence::ByteSequence(sal_Int32 len)'],['../a00614.html#ae969c013613105e42445808e94aca01b',1,'rtl::ByteSequence::ByteSequence(sal_Int32 len, enum __ByteSequence_NoDefault nodefault)'],['../a00614.html#aa70daf1245339b3b88cfe75e4aaffe93',1,'rtl::ByteSequence::ByteSequence(sal_Sequence *pSequence, enum __ByteSequence_NoAcquire noacquire)']]]
];

==> libreoffice-fresh-sdk-25.2.2-1-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/search/all_2.js <==
var searchData=
[
  ['basemutex_0',['BaseMutex',['../a01026.html',1,'cppu']]],
  ['basemutex_2ehxx_1',['basemutex.hxx',['../a00383.html',1,'']]],
  ['basereference_2',['BaseReference',['../a01966.html',1,'com::sun::star::uno']]],
  ['basic_20logging_20functionality_3',['Basic logging functionality.',['../a02540.html',1,'']]],
  ['bcomplete_4',['bComplete',['../a00898.html#a5554ca9c80e573aba7b98aaab7630025',1,'_typelib_TypeDescription']]],
  ['bdisposed_5',['bDisposed',['../a01874.html#a929dd79785e30217bc7d53152c1b455a',1,'cppu::OBroadcastHelperVar']]],
  ['begin_6',['begin',['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence::begin()'],['../a01010.html#abe93b8603cfb316737b269bc76475187',1,'com::sun::star::uno::Sequence::begin() const'],['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence&lt; bool &gt;::begin()'],['../a01010.html#abe93b8603cfb316737b269bc76475187',1,'com::sun::star::uno::Sequence&lt; bool &gt;::begin() const']]],
  ['bin_7',['bIn',['../a00918.html#aa87139c0f6c1cc171cb401ff91a6198a',1,'_typelib_MethodParameter::bIn'],['../a00946.html#a4e3c822420f62a1ae07d401247ed4e2c',1,'_typelib_Parameter_Init::bIn']]],
  ['bind_8',['bind',['../a00858.html#a80d4fbebc159b4e4c2b8b60d3f5ff06e',1,'osl::Socket']]],
  ['bindispose_9',['bInDispose',['../a01874.html#a57c18e5807a8402f77d4769b1bc611d3',1,'cppu::OBroadcastHelperVar']]],
  ['blateinitservice_10',['bLateInitService',['../a01326.html#abaeb329d0b5d020ff3fec6ad46f4532f',1,'cppu::ContextEntry_Init']]],
  ['bondemand_11',['bOnDemand',['../a00898.html#a774f9c5fc72998b566fbfb3f58700393',1,'_typelib_TypeDescription']]],
  ['boneway_12',['bOneWay',['../a00926.html#acba9d6edd1ef75f8d760b6a1c2b59d7f',1,'_typelib_InterfaceMethodTypeDescription']]],
  ['boolean_13',['boolean',['../a00666.html#aa54c42c611eb44213b12e708043c9eda',1,'rtl::OString::boolean()'],['../a00754.html#ace4355afd5260ff7cf87a071fad6e1f2',1,'rtl::OUString::boolean()']]],
  ['bootstrap_14',['Bootstrap',['../a00610.html',1,'rtl::Bootstrap'],['../a00610.html#a7c411aba5c30fa1af8c6d53d02f18897',1,'rtl::Bootstrap::Bootstrap()'],['../a00610.html#a91097cd6f5d7a58469680b6915a81306',1,'rtl::Bootstrap::Bootstrap(const rtl::OUString &amp;iniName)']]],
  ['bootstrap_15',['bootstrap',['../a00537.html#ae1242c73574aa1cd60dca5361bec138c',1,'cppu']]],
  ['bootstrap_2eh_16',['bootstrap.h',['../a00119.html',1,'']]],
  ['bootstrap_2ehxx_17',['bootstrap.hxx',['../a02542.html',1,'(Global Namespace)'],['../a02545.html',1,'(Global Namespace)']]],
  ['bootstrapexception_18',['BootstrapException',['../a01030.html',1,'cppu::BootstrapException'],['../a01030.html#a4284f692e076b8c4855f6114d0b774cf',1,'cppu::BootstrapException::BootstrapException()'],['../a01030.html#a8c61f5925bff77185e816993b7761484',1,'cppu::BootstrapException::BootstrapException(const ::rtl::OUString &amp;rMessage)'],['../a01030.html#afe53d91ab3b69e94c8fea478a7a43a33',1,'cppu::BootstrapException::BootstrapException(const BootstrapException &amp;e)']]],
  ['boundlisteners_19',['BoundListeners',['../a01890.html',1,'cppu::PropertySetMixinImpl::BoundListeners'],['../a01890.html#af88d9d09a3f1f435c21a675d861ef476',1,'cppu::PropertySetMixinImpl::BoundListeners::BoundListeners()']]],
  ['bout_20',['bOut',['../a00918.html#ad5c88a40ec2f87cc2884efe5e8bd88d0',1,'_typelib_MethodParameter::bOut'],['../a00946.html#abd69f9d107dcadf0bd897464288ebaf5',1,'_typelib_Parameter_Init::bOut']]],
  ['bparameterizedtype_21',['bParameterizedType',['../a00942.html#a5cdfddabc1d5d18deac8de1a3e6a7a5d',1,'_typelib_StructMember_Init']]],
  ['breadonly_22',['bReadOnly',['../a00930.html#abb9014766239aeb6a5abb6fa465b4b72',1,'_typelib_InterfaceAttributeTypeDescription']]],
  ['by_20osl_5fgetfilestatus_23',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
  ['by_20osl_5fgetvolumeinfo_24',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
  ['byteseq_2eh_25',['byteseq.h',['../a00137.html',1,'']]],
  ['byteseq_2ehxx_26',['byteseq.hxx',['../a00155.html',1,'']]],
  ['byteseq_5fnoacquire_27',['BYTESEQ_NOACQUIRE',['../a00532.html#af08c591ebecc68f9a8df5f98b25e7542a2eeb40d13b914b4160ea05f6ff7c1beb',1,'rtl']]],
  ['byteseq_5fnodefault_28',['BYTESEQ_NODEFAULT',['../a00532.html#a7416169ba5faa7926706f8972385a6a5ad62567965fea0883022c6c5b41a59f01',1,'rtl']]],
  ['bytesequence_29',['ByteSequence',['../a00614.html',1,'rtl::ByteSequence'],['../a00614.html#aba8a538c65b24ac37c9362497fbb61d8',1,'rtl::ByteSequence::ByteSequence()'],['../a00614.html#a3db75655f708f320589189e839922288',1,'rtl::ByteSequence::ByteSequence(const ByteSequence &amp;rSeq)'],['../a00614.html#a52d50f23e52348c97ba3eb96925a335a',1,'rtl::ByteSequence::ByteSequence(sal_Sequence *pSequence)'],['../a00614.html#aa30632f511c14417f3bc4e3c6afc24d7',1,'rtl::ByteSequence::ByteSequence(const sal_Int8 *pElements, sal_Int32 len)'],['../a00614.html#ab12880eb67f9defc60a7973894d3b3c6',1,'rtl::ByteSequence::ByteSequence(sal_Int32 len)'],['../a00614.html#ae969c013613105e42445808e94aca01b',1,'rtl::ByteSequence::ByteSequence(sal_Int32 len, enum __ByteSequence_NoDefault nodefault)'],['../a00614.html#aa70daf1245339b3b88cfe75e4aaffe93',1,'rtl::ByteSequence::ByteSequence(sal_Sequence *pSequence, enum __ByteSequence_NoAcquire noacquire)']]]
];
